==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/midi/src/MIDI_nl_NL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Configureer MIDI Plugin</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>MIDI kanaal</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Init Message</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Ververs</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Outputs</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Inputs</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Deze plugin verzorgt input/output voor MIDI apparaten.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Output niet ondersteund.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Ongeopend</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Ongeldige output</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Input niet ondersteund.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Input</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Input niet ondersteund</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="196"/>
        <source>No error occurred.</source>
        <translation>Er is geen fout opgetreden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="198"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Er is een fout opgetreden tijdens het lezen van het bestand.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="200"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Er is een fout opgetreden tijdens het schrijven naar het bestand.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="202"/>
        <source>A fatal error occurred.</source>
        <translation>Er is een fatale fout opgetreden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="204"/>
        <source>Resource error occurred.</source>
        <translation>Er is een resource fout opgetreden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="206"/>
        <source>The file could not be opened.</source>
        <translation>Het bestand kan niet geopend worden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="208"/>
        <source>The operation was aborted.</source>
        <translation>De bewerking is afgebroken.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="210"/>
        <source>A timeout occurred.</source>
        <translation>Er is een time-out opgetreden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="212"/>
        <source>An unspecified error occurred.</source>
        <translation>Er is een onbekende fout opgetreden. </translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="214"/>
        <source>The file could not be removed.</source>
        <translation>Het bestand kan niet worden verwijderd.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="216"/>
        <source>The file could not be renamed.</source>
        <translation>Het bestand kan niet hernoemd worden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="218"/>
        <source>The position in the file could not be changed.</source>
        <translation>De positie in het bestand kan niet veranderd worden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="220"/>
        <source>The file could not be resized.</source>
        <translation>Het bestand kan niet van grootte veranderd worden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="222"/>
        <source>The file could not be accessed.</source>
        <translation>Het bestand kan niet benaderd worden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="224"/>
        <source>The file could not be copied.</source>
        <translation>Het bestand kan niet gekopieerd worden.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="226"/>
        <source>An unknown error occurred.</source>
        <translation>Er is een onbekende fout opgetreden.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.6.orig.tar.xz: qlcplus-QLC-_4.12.6/plugins/midi/src/MIDI_nl_NL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Configureer MIDI Plugin</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>MIDI kanaal</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Init Message</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Ververs</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Outputs</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Inputs</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Deze plugin verzorgt input/output voor MIDI apparaten.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Output niet ondersteund.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Ongeopend</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Ongeldige output</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Input niet ondersteund.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Input</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Input niet ondersteund</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="112"/>
        <source>No error occurred.</source>
        <translation>Er is geen fout opgetreden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="114"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Er is een fout opgetreden tijdens het lezen van het bestand.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="116"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Er is een fout opgetreden tijdens het schrijven naar het bestand.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="118"/>
        <source>A fatal error occurred.</source>
        <translation>Er is een fatale fout opgetreden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="120"/>
        <source>Resource error occurred.</source>
        <translation>Er is een resource fout opgetreden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="122"/>
        <source>The file could not be opened.</source>
        <translation>Het bestand kan niet geopend worden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="124"/>
        <source>The operation was aborted.</source>
        <translation>De bewerking is afgebroken.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="126"/>
        <source>A timeout occurred.</source>
        <translation>Er is een time-out opgetreden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="128"/>
        <source>An unspecified error occurred.</source>
        <translation>Er is een onbekende fout opgetreden. </translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="130"/>
        <source>The file could not be removed.</source>
        <translation>Het bestand kan niet worden verwijderd.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="132"/>
        <source>The file could not be renamed.</source>
        <translation>Het bestand kan niet hernoemd worden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="134"/>
        <source>The position in the file could not be changed.</source>
        <translation>De positie in het bestand kan niet veranderd worden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="136"/>
        <source>The file could not be resized.</source>
        <translation>Het bestand kan niet van grootte veranderd worden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="138"/>
        <source>The file could not be accessed.</source>
        <translation>Het bestand kan niet benaderd worden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="140"/>
        <source>The file could not be copied.</source>
        <translation>Het bestand kan niet gekopieerd worden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="142"/>
        <source>An unknown error occurred.</source>
        <translation>Er is een onbekende fout opgetreden.</translation>
    </message>
</context>
</TS>
